@@ -278,7 +278,7 @@ def section_force_distribution_3d(ex, ey, ez, pl, nep=2,
                     Vz = Vz1 * one + Wz * xl
                     T = -T1 * one
                     Mz = -Mz1 * one + Vy1 * xl + 0.5 * Wy * xl**2
-                    My = My1 * one + Vz1 * xl + 0.5 * Wz * xl**2
+                    My = -My1 * one - Vz1 * xl - 0.5 * Wz * xl**2
 
                     s = np.column_stack((N, Vy, Vz, T, My, Mz))
 
@@ -317,14 +317,14 @@ def section_force_distribution_3d(ex, ey, ez, pl, nep=2,
                     s[indx, 1] = Vy1  # Vy
                     s[indx, 2] = Vz1  # Vz
                     s[indx, 3] = -T1  # T
-                    s[indx, 4] = My1 + Vz1 * x  # My
+                    s[indx, 4] = -My1 - Vz1 * x  # My
                     s[indx, 5] = -Mz1 + Vy1 * x  # Mz
                 elif x > a:
                     s[indx, 0] = -1. * (N1 + Px)  # N
                     s[indx, 1] = Vy1 + Py  # Vy
                     s[indx, 2] = Vz1 + Pz  # Vz
                     s[indx, 3] = -T1  # T
-                    s[indx, 4] = My1 + Vz1 * x + Pz * (x-a)  # My
+                    s[indx, 4] = -My1 - Vz1 * x - Pz * (x-a)  # My
                     s[indx, 5] = -Mz1 + Vy1 * x + Py * (x-a)  # Mz
 
                 indx += 1
@@ -373,7 +373,15 @@ def section_force_diagram_2d(sf_type, sfac=1., nep=17,
         node_supports (bool): True - show the supports.
             Default: True.
 
-        ax: axis object.
+        ax: the axes object.
+
+    Returns:
+        minVal (float): the minimum overall value of the section force.
+
+        maxVal (float): the maximum overall value of the section force.
+
+        ax: the axes object.
+
     Usage:
         See example: demo_portal_frame.py
     """
@@ -389,8 +397,9 @@ def section_force_diagram_2d(sf_type, sfac=1., nep=17,
             fleft, fbottom, fright, ftop = fig_lbrt
             fig.subplots_adjust(left=fleft, bottom=fbottom, right=fright, top=ftop)
 
-    model.plot_model(node_labels=0, element_labels=0, fmt_model=fmt_model_secforce,
-                     node_supports=False, ax=ax)
+    ax = model.plot_model(node_labels=0, element_labels=0,
+                          fmt_model=fmt_model_secforce,
+                          node_supports=False, ax=ax)
 
     maxVal, minVal = -np.inf, np.inf
     ele_tags = ops.getEleTags()
@@ -511,11 +520,11 @@ def section_force_diagram_2d(sf_type, sfac=1., nep=17,
 
     if node_supports:
         node_tags = ops.getNodeTags()
-        model._plot_supports(node_tags, ax)
+        ax = model._plot_supports(node_tags, ax)
 
     # ax.grid(False)
 
-    return minVal, maxVal
+    return minVal, maxVal, ax
 
 
 def section_force_diagram_3d(sf_type, sfac=1., nep=17,
@@ -558,6 +567,13 @@ def section_force_diagram_3d(sf_type, sfac=1., nep=17,
             1 - in the y-axis (default for N, Vy, T, Mz)
             2 - in the z-axis (default for Vz, My)
 
+    Returns:
+        minVal (float): the minimum overall value of the section force.
+
+        maxVal (float): the maximum overall value of the section force.
+
+        ax: the axes object.
+
     Usage:
         See example: demo_cantilever_3el_3d.py
 
@@ -586,8 +602,9 @@ def section_force_diagram_3d(sf_type, sfac=1., nep=17,
 
     ax.view_init(azim=azim, elev=elev)
 
-    model.plot_model(node_labels=0, element_labels=0, fmt_model=fmt_model_secforce,
-                     node_supports=False, ax=ax)
+    ax = model.plot_model(node_labels=0, element_labels=0,
+                          fmt_model=fmt_model_secforce,
+                          node_supports=False, ax=ax)
 
     Ew = model.get_Ew_data_from_ops_domain_3d()
 
@@ -707,4 +724,4 @@ def section_force_diagram_3d(sf_type, sfac=1., nep=17,
                 ax.text(s_p[maxVal_ind, 0], s_p[maxVal_ind, 1], s_p[maxVal_ind, 2],
                         f'{ss[maxVal_ind]:.5g}', va=va, ha=ha)
 
-    return minVal, maxVal
+    return minVal, maxVal, ax
